==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/EntityrelationshipCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Entityrelationship;
import microsoft.dynamics.crm.entity.request.EntityrelationshipRequest;
import microsoft.dynamics.crm.entity.request.SolutioncomponentrelationshipconfigurationRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class EntityrelationshipCollectionRequest extends CollectionPageEntityRequest<Entityrelationship, EntityrelationshipRequest>{

    protected ContextPath contextPath;

    public EntityrelationshipCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Entityrelationship.class, cp -> new EntityrelationshipRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SolutioncomponentrelationshipconfigurationCollectionRequest entityrelationship_config() {
        return new SolutioncomponentrelationshipconfigurationCollectionRequest(contextPath.addSegment("entityrelationship_config"), Optional.empty());
    }

    public SolutioncomponentrelationshipconfigurationRequest entityrelationship_config(String solutioncomponentrelationshipconfigurationid) {
        return new SolutioncomponentrelationshipconfigurationRequest(contextPath.addSegment("entityrelationship_config").addKeys(new NameValue(solutioncomponentrelationshipconfigurationid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/EntityrelationshipCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Entityrelationship;
import microsoft.dynamics.crm.entity.request.EntityrelationshipRequest;
import microsoft.dynamics.crm.entity.request.SolutioncomponentrelationshipconfigurationRequest;

public class EntityrelationshipCollectionRequest extends CollectionPageEntityRequest<Entityrelationship, EntityrelationshipRequest>{

    protected ContextPath contextPath;

    public EntityrelationshipCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Entityrelationship.class, cp -> new EntityrelationshipRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SolutioncomponentrelationshipconfigurationCollectionRequest entityrelationship_config() {
        return new SolutioncomponentrelationshipconfigurationCollectionRequest(contextPath.addSegment("entityrelationship_config"), Optional.empty());
    }

    public SolutioncomponentrelationshipconfigurationRequest entityrelationship_config(String solutioncomponentrelationshipconfigurationid) {
        return new SolutioncomponentrelationshipconfigurationRequest(contextPath.addSegment("entityrelationship_config").addKeys(new NameValue(solutioncomponentrelationshipconfigurationid.toString())), Optional.empty());
    }

}
